Documentation
¶
Index ¶
Constants ¶
const ( Primary = iota Follower )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AclManager ¶
AclManager containers the struct for bedel to manager the state of aclmanager acls
func New ¶
func New(addr string, username string, password string) *AclManager
New creates a new AclManager
func (*AclManager) CurrentFunction ¶
func (a *AclManager) CurrentFunction() (function int, err error)
CurrentFunction check if the current node is the Primary node
func (*AclManager) FindNodes ¶
func (a *AclManager) FindNodes() (nodes []NodeInfo, err error)
FindNodes returns a list of nodes in the cluster based on the redis info replication command
func (*AclManager) Loop ¶
func (a *AclManager) Loop(ctx context.Context) (err error)
Loop loops through the sync interval and syncs the acls
func (*AclManager) SyncAcls ¶
func (a *AclManager) SyncAcls() (err error)
SyncAcls connects to master node and syncs the acls to the current node
Click to show internal directories.
Click to hide internal directories.